==> MuSE-0.7pre1.tar.gz: MuSE-0.7pre1/gtkgui/docking.cpp <==
/* A Gui in gtk+ for MuSE - Multiple Streaming Engine
 * Copyright (C) 2002 nightolo <night@autistici.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#include <gtk/gtk.h>
#include "generic.h"
#include "pixmaps.h"
#include "gchan.h"
#include "gchan_utils.h"
#include "utils.h"
#include "docking.h"

void dockchan(GtkWidget *w, struct gchan *c)
{
	/* bisogna cambiare il tasto D */
	GtkWidget *win;
	struct gchan *tmp;
	char buf[30];
	
	func("GTK_GUI::dockchan : channel position is %u", c->pos);
	tmp=c;
	gtk_object_ref(GTK_OBJECT(tmp->frami));
	gtk_container_remove(GTK_CONTAINER(maintab), tmp->frami);
	win=gtk_window_new(GTK_WINDOW_TOPLEVEL);
	/* FIXME: remove X , you can use delete_event */
	c->windock=win;
	
	snprintf(buf, sizeof(buf), "Channel[%u]", tmp->idx);
	gtk_window_set_title(GTK_WINDOW(win), buf);
	gtk_signal_connect(GTK_OBJECT(win), "delete_event",
			(GtkSignalFunc)deletedocked, c);
	gtk_container_add(GTK_CONTAINER(win), tmp->frami);
	gtk_widget_destroy(GTK_WIDGET(c->dock));
	c->dock=createpixmap(win, c->dock, stock_add_xpm, 
			"Undock Channel", FALSE);
	gtk_box_pack_start(GTK_BOX(c->hbox), c->dock, FALSE, FALSE, 0);
	
	
	gtk_signal_connect(GTK_OBJECT(c->dock), "clicked",
			(GtkSignalFunc)undock, c);
	gtk_object_unref(GTK_OBJECT(tmp->frami));
	maxpos-=1;
	repack(c->pos);
	c->pos=0; /* chan is docked */
	gtk_widget_show_all(win);
}

void undock(GtkWidget *w, struct gchan *c)
{
	gtk_object_ref(GTK_OBJECT(c->frami));
	gtk_container_remove(GTK_CONTAINER(c->windock), c->frami);
	packchan(c, maxpos+1);
	maxpos+=1;
	gtk_widget_destroy(c->windock);
	gtk_widget_destroy(c->dock);
	c->dock=createpixmap(window, c->dock, stock_remove2_xpm, 
			"Dock Channel", FALSE);
	gtk_box_pack_start(GTK_BOX(c->hbox), c->dock, FALSE, FALSE, 0);
	
	gtk_widget_show_all(c->dock);
	gtk_object_unref(GTK_OBJECT(c->frami));
	gtk_signal_connect(GTK_OBJECT(c->dock), "clicked", 
			(GtkSignalFunc)dockchan, c);

}

void deletedocked(GtkWidget *w, GdkEvent *s, struct gchan *c)
{
	gtk_widget_destroy(w);
	deletech(c->idx);
}

==> MuSE-0.7.2.tar.gz: MuSE-0.7.2/gtkgui/docking.cpp <==
/* A Gui in gtk+ for MuSE - Multiple Streaming Engine
 * Copyright (C) 2002 nightolo <night@autistici.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk/gtk.h>
#include "generic.h"
#include <gchan.h>
#include <gchan_utils.h>
#include <utils.h>
#include <docking.h>

#include <xpm/dock.xpm>
//#include <xpm/undock.xpm>

#include <config.h>

void dockchan(GtkWidget *w, struct gchan *c)
{
	GtkWidget *win;
	struct gchan *tmp;
	char buf[30];
	
	func("GTK_GUI::dockchan : channel position is %u", c->pos);
	tmp=c;
	gtk_object_ref(GTK_OBJECT(tmp->frami));
	gtk_container_remove(GTK_CONTAINER(maintab), tmp->frami);
	win=gtk_window_new(GTK_WINDOW_TOPLEVEL);
	/* FIXME: remove X , you can use delete_event */
	c->windock=win;
	
	snprintf(buf, sizeof(buf), "Channel[%u]", tmp->idx);
	gtk_window_set_title(GTK_WINDOW(win), buf);
	gtk_signal_connect(GTK_OBJECT(win), "delete_event",
			(GtkSignalFunc)deletedocked, c);
	gtk_container_add(GTK_CONTAINER(win), tmp->frami);
	gtk_widget_destroy(GTK_WIDGET(c->dock));
	c->dock=createpixmap(win, c->dock, dock_xpm, 
			"Dock Channel", FALSE);
	gtk_box_pack_start(GTK_BOX(c->hbox), c->dock, FALSE, FALSE, 0);
	
	
	gtk_signal_connect(GTK_OBJECT(c->dock), "clicked",
			(GtkSignalFunc)undock, c);
	gtk_object_unref(GTK_OBJECT(tmp->frami));
	maxpos-=1;
	repack(c->pos);
	c->pos=0; /* chan is docked */
	gtk_widget_show_all(win);
}

void undock(GtkWidget *w, struct gchan *c)
{
	gtk_object_ref(GTK_OBJECT(c->frami));
	gtk_container_remove(GTK_CONTAINER(c->windock), c->frami);
	packchan(c, maxpos+1);
	maxpos+=1;
	gtk_widget_destroy(c->windock);
	gtk_widget_destroy(c->dock);
	c->dock=createpixmap(window, c->dock, dock_xpm, 
			"Undock Channel", FALSE);
	gtk_box_pack_start(GTK_BOX(c->hbox), c->dock, FALSE, FALSE, 0);
	
	gtk_widget_show_all(c->dock);
	gtk_object_unref(GTK_OBJECT(c->frami));
	gtk_signal_connect(GTK_OBJECT(c->dock), "clicked", 
			(GtkSignalFunc)dockchan, c);

}

void deletedocked(GtkWidget *w, GdkEvent *s, struct gchan *c)
{
	gtk_widget_destroy(w);
	deletech(c->idx);
}
